#! /bin/sh
###############################################################################
#
#  kavupdater.sh: grab the latest virus information databases
#
###############################################################################
KAV_PATH=/usr/local/sbin
KAV_UPDATE_PATH=/opt/AVP-UPDATE
KAV_BASES=/var/spool/avp/bases
PATH=/usr/local/bin:${PATH}
export PATH
chdir $KAV_UPDATE_PATH

RUNDEBUG=1

if [ ! -x /usr/local/bin/wget ]; then
    echo "$0: wget must be installed for the updater to run" >&2
    exit 1
fi

OLDMD5SUM=`md5sum $KAV_BASES/*|md5sum`

DESC="Kaspersky Anti-Virus updater"

if [ -r ./AvpUnix.ini ]; then
    INIFILE=./AvpUnix.ini
else    
    if [ -r $KAV_PATH/AvpUnix.ini ]; then
	INIFILE=$KAV_PATH/AvpUnix.ini
    fi
fi

if [ -r $INIFILE ]; then
    eval `egrep '^[A-Za-z]*=' $INIFILE | perl -pe 's/\r//g'`
fi

#
# Test network connection and download latest virus information db
# 
if [ -n "$UpdatePath" ]; then
    DPARMS="$UpdatePath"
else
    if [ -n $1 ]
    then
	echo "Warning! Add new param UpdatePath in your config file AvpUnix.ini"
	exit 1
    fi
    DPARMS=$1
fi

if [ "x$RUNDEBUG" = "x1" ]; then
  echo checking parameters $DPARMS
fi
 
if [ -x $KAV_PATH/checkurl ]; then
if [ "x$RUNDEBUG" = "x1" ]; then
  $KAV_PATH/checkurl -u=$DPARMS -t=5 -d
else
  $KAV_PATH/checkurl -u=$DPARMS -t=15 
fi
fi

if [ $? -eq 0 ]
then
#
#example for checking file list
#URLSLIST="/opt/AVP-UPDATE/urls_list"
#REPORT="/opt/AVP-UPDATE/urlcheck.rpt"
#/opt/AVP-UPDATE/checkurl -f=$URLSLIST -r=$REPORT -t=5 -d
#if [ $? -eq 0 ]
#then
#    DPARMS=`cat $REPORT`

    if [ "x$RUNDEBUG" = "x1" ]; then
      echo "Run kavupdater"
    #$KAV_PATH/kavupdater -uik=$DPARMS -o -y
      $KAV_PATH/kavupdater -uik=$DPARMS -o -y -b=$KAV_BASES -kb
    else
      $KAV_PATH/kavupdater -uik=$DPARMS -o -y -b=$KAV_BASES -kb -wa+=/var/log/kavupdate.log > /dev/null
    fi
    exitCode=$?

    case $exitCode in
     6)
      echo 6 - Found corrupted file and process stoped on it.
      ;;
     4)
      echo 4 - Found corrupted file. 
      ;;
     2)
      echo 2 - Process stoped on corrupted file.
      ;;
     1)
      echo 1 - Antiviral bases not found.
      ;;
     0)
      if [ "x$RUNDEBUG" = "x1" ]; then
        echo 0 - Antiviral bases correctly loaded.
      fi
      ;;
     *)
      echo $exitCode
      echo I dont know this exit code!
    esac
else
    echo "$0: network connection error." >&2
    exit 1
fi

chmod 644 $KAV_BASES/*

if [ $exitCode -eq 0 ]
then

NEWMD5SUM=`md5sum $KAV_BASES/*|md5sum`
  if [ ! "$OLDMD5SUM" = "$NEWMD5SUM" ]; then
    if [ "x$RUNDEBUG" = "x1" ]; then
      echo "Reload KAV daemon"
      /etc/init.d/avpd stop
      sleep 1
      /etc/init.d/avpd start
    else
      echo "Reload KAV daemon"
      /etc/init.d/avpd stop > /dev/null
      sleep 1
      /etc/init.d/avpd start > /dev/null
    fi
  else
    if [ "x$RUNDEBUG" = "x1" ]; then
      echo "Nothing changed, no kavdaemon restart"
    fi
  fi
#then
#    $KAV_PATH/kavdaemon -ka
#    echo "Reload KAV daemon"
#    sleep 1
#    echo "Stop KAV daemon"
#    sleep 10
#    echo "Start KAV daemon"
#    $KAV_PATH/kavdaemon -I0 -Y
fi

exit 0
